﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion


namespace HeuristicLab.Problems.Instances {

  /// <summary>
  /// Describes instances of a Classification
  /// Problem.
  /// </summary>
  public class ClassificationData {
    /// <summary>
    /// The name of the instance
    /// </summary>
    public string Name { get; set; }
    /// <summary>
    /// Optional! The description of the instance
    /// </summary>
    public string Description { get; set; }
    /// <summary>
    /// The target variable of a problem.
    /// </summary>
    public string TargetVariable { get; set; }
    /// <summary>
    /// All variables which are in the problem.
    /// </summary>
    public string[] InputVariables { get; set; }
    /// <summary>
    /// All variables which shall be used to solve the problem.
    /// (Variables wich are not contained by AllowedInputVariables won't be checked initialy, when the problem is created.)
    /// </summary>
    public string[] AllowedInputVariables { get; set; }
    /// <summary>
    /// Start of the trainings partition
    /// </summary>
    public int TrainingPartitionStart { get; set; }
    /// <summary>
    /// End of the trainings partition
    /// </summary>
    public int TrainingPartitionEnd { get; set; }
    /// <summary>
    /// Start of the test partition
    /// </summary>
    public int TestPartitionStart { get; set; }
    /// <summary>
    /// End of the test partition
    /// </summary>
    public int TestPartitionEnd { get; set; }
    /// <summary>
    /// Contains all the values of the variables
    /// </summary>
    public double[,] Values { get; set; }
  }
}
